<?php

namespace FiloBlu\Job\Controller\Index;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\Result\ForwardFactory;
use Magento\Framework\Exception\NotFoundException;
use Magento\Framework\View\Result\PageFactory;
use Magento\Store\Model\ScopeInterface;
use Psr\Log\LoggerInterface;

/**
 * Contact index controller
 */
class Index extends Action
{
    /**
     * Enabled config path
     */
    const XML_PATH_ENABLED = 'filoblu_job_section/general/enabled';
    /**
     * Page Title
     */
    const XML_PATH_PAGE_TITLE = 'filoblu_job_section/general/page_title';
    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;
    /**
     * @var ForwardFactory
     */
    protected $resultForwardFactory;
    /**
     * @var PageFactory
     */
    protected $resultPageFactory;
    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * Index constructor.
     * @param Context $context
     * @param ScopeConfigInterface $scopeConfig
     * @param ForwardFactory $resultForwardFactory
     * @param PageFactory $resultPageFactory
     * @param LoggerInterface $logger
     */
    public function __construct(
        Context $context,
        ScopeConfigInterface $scopeConfig,
        ForwardFactory $resultForwardFactory,
        PageFactory $resultPageFactory,
        LoggerInterface $logger
    ) {
        parent::__construct($context);
        $this->scopeConfig = $scopeConfig;
        $this->resultForwardFactory = $resultForwardFactory;
        $this->resultPageFactory = $resultPageFactory;
        $this->logger = $logger;
    }

    /**
     * Dispatch request
     *
     * @param RequestInterface $request
     * @return ResponseInterface
     * @throws NotFoundException
     */
    public function dispatch(RequestInterface $request)
    {
        if ($this->scopeConfig->isSetFlag(self::XML_PATH_ENABLED, ScopeInterface::SCOPE_STORE)) {
            return parent::dispatch($request);
        }

        throw new NotFoundException(__('Page not found.'));
    }

    /**
     * @return ResponseInterface|\Magento\Framework\Controller\Result\Forward|\Magento\Framework\Controller\ResultInterface|PageFactory
     */
    public function execute()
    {
        /** @var \Magento\Framework\View\Result\Page $resultPage */
        $resultPage = $this->resultPageFactory->create();

        if (!$resultPage) {
            return $this->resultForwardFactory->create()->forward('noroute');
        }

        $pageTitle = $this->scopeConfig->getValue(self::XML_PATH_PAGE_TITLE, ScopeInterface::SCOPE_STORE);
        $resultPage->getConfig()->getTitle()->set(__($pageTitle));
        return $resultPage;
    }
}