<?php

namespace FiloBlu\Job\Helper;

use Magento\Directory\Model\CountryFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\ScopeInterface;

/**
 * Class Data
 * @package FiloBlu\Job\Helper
 */
class Data extends AbstractHelper
{
    /**
     *  @var string
     * */
    const CONFIG_COUNTRIES = 'filoblu_job_section/general/countries_enabled';

    /**
     * Page Title
     */
    const FORM_TITLE = 'filoblu_job_section/general/form_title';

    /**
     * @var ScopeConfigInterface
     */
    public $scopeConfig;

    /**
     * @var CountryFactory
     */
    protected $countryFactory;

    /**
     * @var array
     */
    protected $countries = [];

    /**
     * Data constructor.
     * @param Context $context
     * @param CountryFactory $countryFactory
     */
    public function __construct(
        Context $context,
        CountryFactory $countryFactory
    ) {
        parent::__construct($context);
        $this->scopeConfig = $context->getScopeConfig();
        $this->countryFactory = $countryFactory;
    }

    /**
     * Retrieve form title
     * @return string
     */
    public function getFormTitle()
    {
            return $this->scopeConfig->getValue(self::FORM_TITLE, ScopeInterface::SCOPE_STORE);
    }

    /**
     * Retrieve bool that specify if country select is showable
     * @return bool
     */
    public function isCountryListShow()
    {
        $countriesConfig =
            $this->scopeConfig->getValue(self::CONFIG_COUNTRIES, ScopeInterface::SCOPE_STORE);

        return $countriesConfig;
    }

    /**
     * Retrieve collection country list
     * @param array $departments
     * @return array
     */
    public function getCountryList(array $departments)
    {
        $countryList = [];

        foreach ($departments as $department) {
            if (!isset($department['country']) || empty($department['country'])) {
                continue;
            }

            $country = strtoupper($department['country']);
            $countryList[$country] = $country;
        }

        return $countryList;
    }

    /**
     * Retrieve entity country name
     * @param string $countryCode
     * @return string
     */
    public function getCountryName($countryCode)
    {
        if (!$countryCode) {
            return '';
        }
        if (!isset($this->countries[$countryCode])) {
            $country = $this->countryFactory->create()->loadByCode($countryCode);
            $this->countries[$countryCode] = $country->getName();
        }

        return $this->countries[$countryCode];
    }
}
